--[[
 *  Wago PFC200 Example
 *
 *  Copyright (C) Albrecht Victor <a.victor@web.de>
 *  
 *  This program is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU General Public License
 *  as published by the Free Software Foundation; either version 2
 *  of the License, or (at your option) any later version.
 *  
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *  
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, 
 *  write to the Free Software Foundation, Inc.,
 *  51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
--]]


require("socket")
require "cn"
require "timers"

print("test kbus")

-- open the wago build in lib
sys.wago.open()

-- init the KBus
k=sys.wago.kBusNew()

-- check the console output for KBUS module configuration!

-- assuming a 4 channel DO 750-504 
b=k[1]

-- activate or deactivate channels
b:setBit(1,true) -- turn on 1st channel
b:setBit(2,false)
b:setBit(3,true)
b:setBit(4,true)


-- activate or deactivate using bytes, for 4 channel DO overlapping bits are lost
b:setBytes(1,16)

-- ask if bit is set or not
b:getBitState(0,1) -- ignore first parameter, second is position of bit

-- assuming a 16 channel DI on 3 position
myBytes = k[3]:getBytes(1,1)

-- application example
function switch(value)
  b:setBit(value[1], value[2])
end

lights = {}
lights["living_room_on"] = {1, true}
lights["living_room_off"] = {1, false}
 
switch(lights.living_room_on)
switch(lights.living_room_off)

-- simple implementation to wire DI channel to 2 DO channel
timer1 = timers.add(
     0.01,                                  -- Cycle time seconds
     function()                            -- The function to call
       if(k[3]:getBit(8)) then k[2]:setBit(1,true) else k[2]:setBit(1,false) end
       if(k[3]:getBit(8)) then k[2]:setBit(4,true) else k[2]:setBit(4,false) end
     end,
     'timer1'                              -- Optinal timer name
 )

-- stupid timer
timer2 = timers.add(
     5.0,                                  -- Cycle time seconds
     function()                            -- The function to call
       print('timer02',os.time())
     end,
     'timer2'                              -- Optinal timer name
 )

-- loop
while sys.idle() 
    do 
    sys.sleep(0.01)
    end

